@@ -7,11 +7,12 @@
 (ns puppetlabs.kitchensink.core
   (:import [org.ini4j Ini Config]
            [javax.naming.ldap LdapName]
-           [java.io StringWriter Reader IOException File])
+           [java.io StringWriter Reader File])
   (:require [clojure.test]
             [clojure.tools.logging :as log]
             [clojure.string :as string]
             [clojure.tools.cli :as cli]
+            [clojure.java.io :as io]
             [digest]
             [slingshot.slingshot :refer [throw+]]
             [me.raynes.fs :as fs])
@@ -52,6 +53,12 @@
   {:post [(boolean? %)]}
   (instance? java.util.regex.Pattern regexp))
 
+(defn zipper?
+  "Checks to see if the object has zip/make-node metadata on it (confirming it
+to be a zipper."
+  [obj]
+  (contains? (meta obj) :zip/make-node))
+
 ;; ## String utilities
 
 (defn strict-parse-bool
@@ -106,6 +113,33 @@
     (pprint x w)
     (.toString w)))
 
+(defn to-sentence
+  "Join the given strings as they would be listed in a sentence (using an Oxford
+  comma if there are three or more strings).
+  Examples:
+    [\"apple\"] => \"apple\"
+    [\"apple\" \"orange\"] => \"apple and orange\"
+    [\"apple\" \"orange\" \"banana\"] => \"apple, orange, and banana\""
+  [strings]
+  (let [num-strings (count strings)]
+    (cond
+      (empty? strings)
+      ""
+
+      (= num-strings 1)
+      (first strings)
+
+      (= num-strings 2)
+      (str (first strings) " and " (second strings))
+
+      (= num-strings 3)
+      (let [[s0 s1 s2] strings]
+        (str s0 ", " s1 ", and " s2))
+
+      (> num-strings 3)
+      (str (first strings) ", " (to-sentence (rest strings))))))
+
+
 ;; ## I/O
 
 (defn lines
@@ -198,6 +232,27 @@
    :post [(or (number? %) (nil? %))]}
   ((some-fn parse-int parse-float) s))
 
+;; ## Randomness
+
+(defn rand-weighted-selection
+  "Given alternating numeric weights and values, produces a randomly-selected
+  value according to the weights, which should sum to one.  If the weights sum
+  to less than one, then the last value will have its weight adjusted upwards
+  accordingly. If the weights sum to more than one, then values after the
+  cumulative sum of the weights exceeds one will never be selected."
+  [& weights-and-values]
+  {:pre [(even? (count weights-and-values))
+         (every? number? (take-nth 2 weights-and-values))]}
+  (let [weights (take-nth 2 weights-and-values)
+        values (-> (take-nth 2 (drop 1 weights-and-values)) butlast)
+        cutoffs (-> (reductions + weights) butlast)
+        selected? (let [selected-cutoff (rand)]
+                    #(>= % selected-cutoff))
+        selected (filter (comp selected? first)
+                         (map vector cutoffs values))]
+    (if (empty? selected)
+      (last weights-and-values)
+      (-> (first selected) second))))
 
 ;; ## Collection operations
 
@@ -308,6 +363,11 @@
         (when-not (empty? res)
           res)))))
 
+(defn walk-leaves
+  "Walk a map applying a function to all leaf nodes"
+  [m f]
+  (mapvals #(if (map? %) (walk-leaves % f) (f %)) m))
+
 (defn merge-with-key
   "Returns a map that consists of the rest of the maps conj-ed onto
   the first.  If a key `k` occurs in more than one map, the mapping(s)
@@ -383,6 +443,19 @@
   "Returns the sequence of values from the map for the entries with the specified keys"
   (comp vals select-keys))
 
+(defn filter-map
+  "Like 'filter', but works on maps.  Returns a map containing the
+  key-value pairs in 'm' for which 'pred' returns a truth-y value.
+  'pred' must be a function which takes two arguments."
+  [pred m]
+  (reduce
+    (fn [result [key value]]
+      (if (pred key value)
+        (assoc result key value)
+        result))
+    {}
+    m))
+
 (defn missing?
   "Inverse of contains? that supports multiple keys. Will return true if all items are
   missing from the collection, false otherwise.
@@ -528,8 +601,34 @@
      (catch Throwable e#
        (deliver ~error e#))))
 
+(defmacro with-timeout [timeout-s default & body]
+  `(let [f# (future (do ~@body))
+         result# (deref f# (* 1000 ~timeout-s) ~default)]
+     (future-cancel f#)
+     result#))
+
+;; ## File paths
+(defn absolute-path
+  "Replacement for raynes.fs/absolute-path, which was removed in raynes.fs 1.4.6.
+  Returns string representation of absolute path, as opposed to fs/absolute, which
+  returns a File object."
+  [path]
+  (.getPath (fs/absolute path)))
+
+(defn normalized-path
+  "Replacement for raynes.fs/normalized-path, which was removed in raynes.fs 1.4.6.
+  Returns string representation of absolute path, as opposed to fs/normalized, which
+  returns a File object."
+  [path]
+  (.getPath (fs/normalized path)))
+
 ;; ## Temp files
 
+(defn temp-file-name
+  "Returns a unique name to a temporary file, but does not actually create the file."
+  [file-name-prefix]
+  (io/file (fs/tmpdir) (fs/temp-name file-name-prefix)))
+
 (defn delete-on-exit
   "Will delete `f` on shutdown of the JVM"
   [f]
@@ -642,7 +741,7 @@
                   [path]
                   (fs/glob (fs/file path glob-pattern)))]
       (->> files
-        (map fs/absolute-path)
+        (map fs/absolute)
         (map ini-to-map)
         (apply deep-merge-with-keys
                (fn [ks & _]
@@ -895,6 +994,15 @@
            ~expr
            (cond-let ~bindings ~@more))))))
 
+(defmacro while-let
+  "Repeatedly executes body while test expression is true, evaluating the body
+  with binding-form bound to the value of test."
+  [bindings & body]
+  (let [form (first bindings) test (second bindings)]
+    `(loop [~form ~test]
+       (when ~form
+         ~@body
+         (recur ~test)))))
 
 (defmacro some-pred->>
   "When expr does not satisfy pred, threads it into the first form (via ->>),
