@@ -97,6 +97,14 @@
 (def CertificateRevocationList
   (schema/pred utils/certificate-revocation-list?))
 
+(def OutcomeInfo
+  "Generic map of outcome & message for API consumers"
+  {:outcome (schema/enum :success :not-found :error)
+   :message schema/Str})
+
+(def OIDMappings
+  {schema/Str schema/Keyword})
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Definitions
 
@@ -155,6 +163,10 @@
   "The set of SSL related files that are required on the CA."
   #{:cacert :cacrl :cakey :cert-inventory :serial})
 
+(def max-ca-ttl
+  "The longest valid duration for CA certs, in seconds. 50 standard years."
+  1576800000)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Internal
 
@@ -398,6 +410,40 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Initialization
 
+(schema/defn validate-settings!
+  "Ensure config values are valid for basic CA behaviors."
+  [settings :- CaSettings]
+  (let [ca-ttl (:ca-ttl settings)
+        certificate-status-access-control (get-in settings
+                                                  [:access-control
+                                                   :certificate-status])
+        certificate-status-whitelist (:client-whitelist
+                                       certificate-status-access-control)]
+    (when (> ca-ttl max-ca-ttl)
+      (throw (IllegalStateException.
+               (format "Config setting ca_ttl must have a value below %s" max-ca-ttl))))
+    (cond
+      (or (false? (:authorization-required certificate-status-access-control))
+          (not-empty certificate-status-whitelist))
+      (log/warn
+        "The 'client-whitelist' and 'authorization-required' settings in the"
+        "'certificate-authority.certificate-status' section are deprecated and"
+        "will be removed in a future release.  Remove these settings and create"
+        "an appropriate authorization rule in the"
+        "/etc/puppetlabs/puppetserver/conf.d/auth.conf file.")
+      (not (nil? certificate-status-whitelist))
+      (log/warn
+        "The 'client-whitelist' and 'authorization-required' settings in the"
+        "'certificate-authority.certificate-status' section are deprecated"
+        "and will be removed in a future release.  Because the"
+        "'client-whitelist' is empty and 'authorization-required' is set to"
+        "'false', the 'certificate-authority.certificate-status' settings"
+        "will be ignored and authorization for the 'certificate_status'"
+        "endpoints will be done per the authorization rules in the"
+        "/etc/puppetlabs/puppetserver/conf.d/auth.conf file.  To suppress"
+        "this warning, remove the 'certificate-authority' configuration"
+        "settings."))))
+
 (schema/defn create-ca-extensions :- (schema/pred utils/extension-list?)
   "Create a list of extensions to be added to the CA certificate."
   [ca-name :- (schema/pred utils/valid-x500-name?)
@@ -550,19 +596,17 @@
   "Parse the CSR attributes yaml file at the given path and create a list of
   certificate extensions from the `extensions_requests` section."
   [csr-attributes-file :- schema/Str]
-  (when (fs/file? csr-attributes-file)
-    (try
-      (let [csr-attrs (yaml/parse-string (slurp csr-attributes-file))
-            ext-req   (:extension_requests csr-attrs)]
-        (map (fn [[oid value]]
-               {:oid      (or (get puppet-short-names oid)
-                              (name oid))
-                :critical false
-                :value    (str value)})
-             ext-req))
-      (catch Exception e
-        (throw (Exception.
-                 (str "There was a problem parsing " csr-attributes-file) e))))))
+  (if (fs/file? csr-attributes-file)
+    (let [csr-attrs (yaml/parse-string (slurp csr-attributes-file))
+          ext-req (:extension_requests csr-attrs)]
+      (map (fn [[oid value]]
+             {:oid (or (get puppet-short-names oid)
+                       (name oid))
+              :critical false
+              :value (str value)})
+           ext-req))
+    (log/debugf "No CSR Attributes configuration file found at %s, CSR Attributes will not be loaded"
+                csr-attributes-file)))
 
 (schema/defn create-master-extensions :- (schema/pred utils/extension-list?)
   "Create a list of extensions to be added to the master certificate."
@@ -743,7 +787,9 @@
    the CSR stream will be provided on standard-in. The ruby-load-path will be
    prepended to the RUBYLIB found in the environment, and is intended to make
    the Puppet and Facter Ruby libraries available to the autosign script.
-   All output (stdout & stderr) will be logged at the debug level."
+   All output (stdout & stderr) will be logged at the debug level. Warnings are
+   issued for nonzero exit code or if stderr is generated by the autosign
+   script."
   [executable :- schema/Str
    subject :- schema/Str
    csr-stream :- InputStream
@@ -761,9 +807,16 @@
                   :in csr-stream
                   :env (merge env {"RUBYLIB" rubylib})})]
     (log/debugf "Autosign command '%s %s' exit status: %d"
-                executable subject (:exit results))
-    (log/debugf "Autosign command '%s %s' output: %s"
-                executable subject (str (:err results) (:out results)))
+                executable subject (:exit-code results))
+    (log/debugf "Autosign command '%s %s' output on stdout: %s"
+                executable subject (:stdout results))
+    (when-not (empty? (:stderr results))
+      (log/warnf "Autosign command '%s %s' generated output to stderr: %s"
+                 executable subject (:stderr results)))
+    (when-not (zero? (:exit-code results))
+      (log/warnf (str "Autosign command '%s' rejected certificate '%s' because "
+                      "the exit code was %s, not zero")
+                 executable subject (:exit-code results)))
     results))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -773,8 +826,8 @@
   config->ca-settings :- CaSettings
   "Given the configuration map from the Puppet Server config
    service return a map with of all the CA settings."
-  [{:keys [puppet-server jruby-puppet certificate-authority]}]
-  (-> (select-keys puppet-server (keys CaSettings))
+  [{:keys [puppetserver jruby-puppet certificate-authority]}]
+  (-> (select-keys puppetserver (keys CaSettings))
       (assoc :ruby-load-path (:ruby-load-path jruby-puppet))
       (assoc :access-control (select-keys certificate-authority
                                           [:certificate-status]))))
@@ -783,8 +836,8 @@
   config->master-settings :- MasterSettings
   "Given the configuration map from the Puppet Server config
   service return a map with of all the master settings."
-  [{:keys [puppet-server]}]
-  (select-keys puppet-server (keys MasterSettings)))
+  [{:keys [puppetserver]}]
+  (select-keys puppetserver (keys MasterSettings)))
 
 (schema/defn ^:always-validate
   get-certificate :- (schema/maybe schema/Str)
@@ -823,7 +876,6 @@
     (if (fs/exists? autosign)
       (if (fs/executable? autosign)
         (let [command-result (execute-autosign-command! autosign subject csr-stream ruby-load-path)]
-          (log/debug (:stdout command-result))
           (-> command-result
               :exit-code
               zero?))
@@ -871,7 +923,7 @@
                                             (create-agent-extensions
                                              csr
                                              (.getPublicKey cacert)))]
-    (log/debug "Signed certificate request for" subject)
+    (log/info "Signed certificate request for" subject)
     (write-cert-to-inventory! signed-cert cert-inventory)
     (utils/cert->pem! signed-cert (path-to-cert signeddir subject))))
 
@@ -953,6 +1005,28 @@
         (autosign-certificate-request! subject csr settings)
         (fs/delete (path-to-cert-request csrdir subject))))))
 
+(schema/defn ^:always-validate delete-certificate-request! :- OutcomeInfo
+  "Delete pending certificate requests for subject"
+  [{:keys [csrdir]} :- CaSettings
+   subject :- schema/Str]
+  (let [csr-path (path-to-cert-request csrdir subject)]
+    (if (fs/exists? csr-path)
+      (if (fs/delete csr-path)
+        (let [msg (str "Deleted certificate request for " subject)]
+          (log/debug msg)
+          {:outcome :success
+           :message msg})
+        (let [msg (format "Path %s exists but could not be deleted" csr-path)]
+          (log/error msg)
+          {:outcome :error
+           :message msg}))
+      (let [msg (format
+                  "No certificate request for %s at expected path %s"
+                  subject csr-path)]
+        (log/warn msg)
+        {:outcome :not-found
+         :message msg }))))
+
 (schema/defn ^:always-validate
   get-certificate-revocation-list :- schema/Str
   "Given the value of the 'cacrl' setting from Puppet,
@@ -1145,15 +1219,26 @@
         message))))
 
 (schema/defn ^:always-validate delete-certificate!
-  "Delete the certificate and/or CSR for the given subject.
+  "Delete the certificate for the given subject.
    Note this does not revoke the certificate."
-  [{:keys [csrdir signeddir]} :- CaSettings
+  [{signeddir :signeddir} :- CaSettings
    subject :- schema/Str]
-  (let [cert (path-to-cert signeddir subject)
-        csr  (path-to-cert-request csrdir subject)]
+  (let [cert (path-to-cert signeddir subject)]
     (when (fs/exists? cert)
       (fs/delete cert)
-      (log/debug "Deleted certificate for" subject))
-    (when (fs/exists? csr)
-      (fs/delete csr)
-      (log/debug "Deleted certificate request for" subject))))
+      (log/debug "Deleted certificate for" subject))))
+
+(schema/defn ^:always-validate get-custom-oid-mappings :- (schema/maybe OIDMappings)
+  "Given a path to a custom OID mappings file, return a map of all oids to
+  shortnames"
+  [custom-oid-mapping-file :- schema/Str]
+  (if (fs/file? custom-oid-mapping-file)
+    (let [oid-mappings (:oid_mapping (yaml/parse-string (slurp custom-oid-mapping-file)))]
+      (into {} (for [[oid names] oid-mappings] [(name oid) (keyword (:shortname names))])))
+    (log/debugf "No custom OID mapping configuration file found at %s, custom OID mappings will not be loaded"
+                custom-oid-mapping-file)))
+
+(schema/defn ^:always-validate get-oid-mappings :- OIDMappings
+  [custom-oid-mapping-file :- (schema/maybe schema/Str)]
+  (merge (get-custom-oid-mappings custom-oid-mapping-file)
+         (clojure.set/map-invert puppet-short-names)))
\ No newline at end of file
