@@ -3,8 +3,9 @@
            (clojure.lang IFn))
   (:require [puppetlabs.puppetserver.certificate-authority :as ca]
             [puppetlabs.puppetserver.ringutils :as ringutils]
+            [puppetlabs.ring-middleware.core :as middleware]
             [puppetlabs.puppetserver.liberator-utils :as liberator-utils]
-            [puppetlabs.comidi :as comidi :refer [GET ANY PUT]]
+            [puppetlabs.comidi :as comidi :refer [GET ANY PUT DELETE]]
             [bidi.schema :as bidi-schema]
             [slingshot.slingshot :as sling]
             [clojure.tools.logging :as log]
@@ -51,9 +52,7 @@
     (catch ca/csr-validation-failure? {:keys [message]}
       (log/error message)
       ;; Respond to all CSR validation failures with a 400
-      (-> (rr/response message)
-          (rr/status 400)
-          (rr/content-type "text/plain")))))
+      (middleware/plain-response 400 message))))
 
 (defn handle-get-certificate-revocation-list
   [{:keys [cacrl]}]
@@ -61,6 +60,15 @@
       (rr/response)
       (rr/content-type "text/plain")))
 
+(schema/defn handle-delete-certificate-request!
+  [subject :- String
+   ca-settings :- ca/CaSettings]
+  (let [response (ca/delete-certificate-request! ca-settings subject)
+        outcomes->codes {:success 204 :not-found 404 :error 500}]
+    (-> (rr/response (:message response))
+        (rr/status ((response :outcome) outcomes->codes))
+        (rr/content-type "text/plain"))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Web app
 
@@ -167,7 +175,8 @@
 
   :delete!
   (fn [context]
-    (ca/delete-certificate! settings subject))
+    (ca/delete-certificate! settings subject)
+    (ca/delete-certificate-request! settings subject))
 
   :exists?
   (fn [context]
@@ -207,13 +216,16 @@
     (when (= :put (get-in context [:request :request-method]))
       (if-let [body (get-in context [:request :body])]
         (if-let [json-body (try-to-parse body)]
-          (let [desired-state (keyword (:desired_state json-body))]
+          (if-let [desired-state (keyword (:desired_state json-body))]
             (if (schema/check ca/DesiredCertificateState desired-state)
               (malformed
                 (format
                   "State %s invalid; Must specify desired state of 'signed' or 'revoked' for host %s."
                   (name desired-state) subject))
-              [false {::json-body json-body}]))
+              ; this is the happy path. we have a body, it's parsable json,
+              ; and the desired_state field is one of (signed revoked)
+              [false {::json-body json-body}])
+            (malformed "Missing required parameter \"desired_state\""))
           (malformed "Request body is not JSON."))
         (malformed "Empty request body."))))
 
@@ -259,8 +271,10 @@
     (comidi/context ["/v1"]
       (ANY ["/certificate_status/" :subject] [subject]
         (certificate-status subject ca-settings))
-      (ANY ["/certificate_statuses/" :ignored-but-required] []
-        (certificate-statuses ca-settings))
+      (comidi/context ["/certificate_statuses/"]
+        (ANY [[#"[^/]+" :ignored-but-required]] []
+          (certificate-statuses ca-settings))
+        (ANY [""] [] (middleware/plain-response 400 "Missing URL Segment")))
       (GET ["/certificate/" :subject] [subject]
         (handle-get-certificate subject ca-settings))
       (comidi/context ["/certificate_request/" :subject]
@@ -268,6 +282,8 @@
           (handle-get-certificate-request subject ca-settings))
         (PUT [""] [subject :as {body :body}]
           (handle-put-certificate-request! subject body ca-settings)))
+        (DELETE [""] [subject]
+          (handle-delete-certificate-request! subject ca-settings))
       (GET ["/certificate_revocation_list/" :ignored-node-name] []
         (handle-get-certificate-revocation-list ca-settings)))
     (comidi/not-found "Not Found")))
@@ -278,9 +294,9 @@
    puppet-version :- schema/Str]
   (-> handler
     ;(liberator-dev/wrap-trace :header)           ; very useful for debugging!
-      (ringutils/wrap-exception-handling)
+      (middleware/wrap-uncaught-errors :plain)
       (ringutils/wrap-with-puppet-version-header puppet-version)
-      (ringutils/wrap-response-logging)))
+      (middleware/wrap-response-logging)))
 
 (schema/defn ^:always-validate
   get-wrapped-handler :- IFn
